@@ -21,6 +21,13 @@ package Data::FormValidator::ConstraintsFactory;
 
 Data::FormValidator::ConstraintsFactory - Module to create constraints for HTML::FormValidator.
 
+=head1 DESCRIPTION
+
+This module contains functions to help generate complex constraints. 
+
+If you are writing new code, take a look at L<Data::FormValidator::Constraints::MethodsFactory>
+instead. It's a modern alternative to what's here, offering improved names and syntax. 
+
 =head1 SYNOPSIS
 
     use Data::FormValidator::ConstraintsFactory qw( :set :bool );
@@ -34,11 +41,6 @@ Data::FormValidator::ConstraintsFactory - Module to create constraints for HTML:
 	bid	 => make_range_constraint( 1, 1, 10 ),
     }
 
-=head1 DESCRIPTION
-
-This module contains several functions which returns closures that can
-be used for constraints.
-
 =cut
 
 use vars qw( $VERSION @ISA @EXPORT @EXPORT_OK %EXPORT_TAGS );
@@ -46,7 +48,7 @@ use vars qw( $VERSION @ISA @EXPORT @EXPORT_OK %EXPORT_TAGS );
 BEGIN {
     require Exporter;
 
-    $VERSION = 1.4;
+    $VERSION = 1.6; 
 
     @ISA = qw( Exporter );
 
@@ -101,7 +103,7 @@ sub make_or_constraint {
     # Closure
     return sub {
 	my $res;
-	foreach my $c ( @c ) {
+	for my $c ( @c ) {
 	    $res = $c->( @_ );
 	    return $res if $res;
 	}
@@ -123,7 +125,7 @@ sub make_and_constraint {
     # Closure
     return sub {
 	my $res;
-	foreach my $c ( @c ) {
+	for my $c ( @c ) {
 	    $res = $c->( @_ );
 	    return $res if ! $res;
 
@@ -155,7 +157,7 @@ sub make_set_constraint {
     # Closure
     return sub {
 	my $v = $_[0];
-	foreach my $t ( @values ) {
+	for my $t ( @values ) {
 	    return $res if $t eq $v;
 	}
 	return ! $res;
@@ -178,7 +180,7 @@ sub make_num_set_constraint {
     # Closure
     return sub {
 	my $v = $_[0];
-	foreach my $t ( @values ) {
+	for my $t ( @values ) {
 	    return $res if $t == $v;
 	}
 	return ! $res;
@@ -223,7 +225,7 @@ sub make_match_set_constraint {
     # Closure
     return sub {
 	my $v = $_[0];
-	foreach my $t ( @values ) {
+	for my $t ( @values ) {
 	    return $res if $cmp->($v, $t );
 	}
 	return ! $res;
